//
//  GSComponent.h
//  Glyphs
//
//  Created by Georg Seifert on 30.3.08.
//  Copyright 2008 schriftgestaltung.de. All rights reserved.
//

#import <GlyphsCore/GSTransformableElement.h>
#import <Cocoa/Cocoa.h>

#ifndef LIBCORE

#import <GlyphsCore/SCEventListenerProtocol.h>

#endif

/** GSBackgroundImage: The class defining the image

 It is a subclass of GSElement
 */
@interface GSBackgroundImage : GSTransformableElement {
	NSRect _crop;
}

/// @name Initialisation

/** Inits with a NSURL
 
 @param URL the URL
 */
- (instancetype)initWithURL:(NSURL *)URL;

- (instancetype)initWithData:(NSData *)imageData imageType:(NSString *)imageType;

/// the image path
@property (strong, nonatomic) NSString *imagePath;
/// the image URL
@property (strong, nonatomic) NSURL *imageURL;
/// the NSImage
@property (readonly, nonatomic) NSImage *image;

@property (strong, nonatomic) NSData *imageData;

@property (strong, nonatomic) NSString *imageType;
/// The Crop
@property (assign, nonatomic) NSRect crop;
/// transparency of rendering in outline mode.
@property (assign, nonatomic) unsigned short alpha;

- (BOOL)isEqualToBackgroundImage:(GSBackgroundImage *)other;

#ifndef GLYPHS_VIEWER
/// Shows the image in the Finder
- (void)showInFinder:(id)sender;

/// toggle locked
- (void)toggleLocked;
#endif

- (BOOL)hasValidImageToDraw;

- (BOOL)hasImageToDraw;

- (void)reloadImage;

@end
